@@ -13,18 +13,19 @@ Usage::
     client: OutpostsClient = session.client("outposts")
     ```
 """
-import sys
 from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     AddressTypeType,
+    AssetStateType,
     CatalogItemClassType,
     FiberOpticCableTypeType,
     MaximumSupportedWeightLbsType,
     OpticalStandardType,
     PaymentOptionType,
+    PaymentTermType,
     PowerConnectorType,
     PowerDrawKvaType,
     PowerFeedDropType,
@@ -61,12 +62,6 @@ from .type_defs import (
     UpdateSiteRackPhysicalPropertiesOutputTypeDef,
 )
 
-if sys.version_info >= (3, 9):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("OutpostsClient",)
 
 
@@ -115,7 +110,7 @@ class OutpostsClient(BaseClient):
 
     def cancel_order(self, *, OrderId: str) -> Dict[str, Any]:
         """
-        Cancels an order for an Outpost.
+        Cancels the specified order for an Outpost.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.cancel_order)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#cancel_order)
@@ -135,7 +130,7 @@ class OutpostsClient(BaseClient):
         OutpostIdentifier: str,
         LineItems: Sequence[LineItemRequestTypeDef],
         PaymentOption: PaymentOptionType,
-        PaymentTerm: Literal["THREE_YEARS"] = ...
+        PaymentTerm: PaymentTermType = ...
     ) -> CreateOrderOutputTypeDef:
         """
         Creates an order for an Outpost.
@@ -182,7 +177,7 @@ class OutpostsClient(BaseClient):
 
     def delete_outpost(self, *, OutpostId: str) -> Dict[str, Any]:
         """
-        Deletes the Outpost.
+        Deletes the specified Outpost.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.delete_outpost)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#delete_outpost)
@@ -190,7 +185,7 @@ class OutpostsClient(BaseClient):
 
     def delete_site(self, *, SiteId: str) -> Dict[str, Any]:
         """
-        Deletes the site.
+        Deletes the specified site.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.delete_site)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#delete_site)
@@ -212,7 +207,7 @@ class OutpostsClient(BaseClient):
 
     def get_catalog_item(self, *, CatalogItemId: str) -> GetCatalogItemOutputTypeDef:
         """
-        Gets information about a catalog item.
+        Gets information about the specified catalog item.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.get_catalog_item)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#get_catalog_item)
@@ -228,7 +223,7 @@ class OutpostsClient(BaseClient):
 
     def get_order(self, *, OrderId: str) -> GetOrderOutputTypeDef:
         """
-        Gets an order.
+        Gets information about the specified order.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.get_order)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#get_order)
@@ -264,7 +259,7 @@ class OutpostsClient(BaseClient):
         self, *, SiteId: str, AddressType: AddressTypeType
     ) -> GetSiteAddressOutputTypeDef:
         """
-        Gets the site address.
+        Gets the site address of the specified site.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.get_site_address)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#get_site_address)
@@ -276,10 +271,11 @@ class OutpostsClient(BaseClient):
         OutpostIdentifier: str,
         HostIdFilter: Sequence[str] = ...,
         MaxResults: int = ...,
-        NextToken: str = ...
+        NextToken: str = ...,
+        StatusFilter: Sequence[AssetStateType] = ...
     ) -> ListAssetsOutputTypeDef:
         """
-        Lists the hardware assets in an Outpost.
+        Lists the hardware assets for the specified Outpost.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.list_assets)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#list_assets)
@@ -401,7 +397,7 @@ class OutpostsClient(BaseClient):
         self, *, SiteId: str, Name: str = ..., Description: str = ..., Notes: str = ...
     ) -> UpdateSiteOutputTypeDef:
         """
-        Updates the site.
+        Updates the specified site.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.update_site)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#update_site)
@@ -411,7 +407,7 @@ class OutpostsClient(BaseClient):
         self, *, SiteId: str, AddressType: AddressTypeType, Address: AddressTypeDef
     ) -> UpdateSiteAddressOutputTypeDef:
         """
-        Updates the site address.
+        Updates the address of the specified site.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.update_site_address)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#update_site_address)
